# basal_and_bark


[![image](https://img.shields.io/pypi/v/basal_and_bark.svg)](https://pypi.python.org/pypi/basal_and_bark)
[![image](https://img.shields.io/conda/vn/conda-forge/basal_and_bark.svg)](https://anaconda.org/conda-forge/basal_and_bark)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/basal-and-bark/badges/version.svg)](https://anaconda.org/conda-forge/basal-and-bark)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/basal-and-bark/badges/downloads.svg)](https://anaconda.org/conda-forge/basal-and-bark)


**Welcome to Basal and Bark, a spatial python package for working with forest data!**


-   Free software: MIT license
-   Documentation: https://ZachDorm.github.io/basal_and_bark
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
